pub struct DnsCache { /* private fields */ }Expand description
Cache for DNS records with automatic expiration.
The cache stores records along with their fetch timestamp and expires after a configurable TTL to ensure data freshness.
Implementations
Sourceimpl DnsCache
impl DnsCache
Sourcepub fn new(ttl: Duration) -> Self
pub fn new(ttl: Duration) -> Self
Create a new DNS record cache.
Arguments
ttl- How long to keep records cached before requiring a refresh
Sourcepub fn with_default_ttl() -> Self
pub fn with_default_ttl() -> Self
Create a cache with default 60-second TTL.
Sourcepub fn get(&self) -> Option<&Vec<DnsRecord>>
pub fn get(&self) -> Option<&Vec<DnsRecord>>
Get cached records if valid, otherwise returns None.
Sourcepub fn invalidate(&mut self)
pub fn invalidate(&mut self)
Force invalidate the cache.
Sourcepub fn remaining_ttl(&self) -> Option<Duration>
pub fn remaining_ttl(&self) -> Option<Duration>
Get remaining TTL before cache expires.