pub struct Config {
pub cloudflare_api_token: String,
pub cloudflare_zone_id: String,
}Fields
cloudflare_api_token: Stringcloudflare_zone_id: StringImplementations
Sourceimpl Config
impl Config
Sourcepub fn load() -> Result<Self>
pub fn load() -> Result<Self>
Load configuration with fallback chain:
- ~/.config/cloudflaredns/config.yaml
- ./.env (current directory)
- Environment variables
Sourcepub fn load_from_env() -> Result<Self>
pub fn load_from_env() -> Result<Self>
Load configuration from environment variables only. Useful for testing or when no config file is available.
Sourcepub fn config_path() -> PathBuf
pub fn config_path() -> PathBuf
Get the expected config file path for display purposes