Background task definitions for async operations.
This module contains all the async tasks that interact with the Cloudflare API and update application state. Parameter objects are used to reduce function argument counts and improve readability.
Structs
- Delete
Params - Parameters for the delete task.
Functions
- delete_
task - Execute a DNS record deletion with automatic refresh on success.